"Echo" Deltabot example plugin
==============================

This serves as an example for how to write and package plugins
with standard Python packaging machinery.

The echo plugin registers a single `/echo` command that end-users
can send to the bot.

